"""removed unique logged in user

Peek Plugin Database Migration Script

Revision ID: 5e33c6b788fd
Revises: 3fd59734e444
Create Date: 2019-07-19 15:00:09.318828

"""

# revision identifiers, used by Alembic.
revision = '5e33c6b788fd'
down_revision = '3fd59734e444'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint('UserLoggedIn_userName_key', 'UserLoggedIn', schema='core_user', type_='unique')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_unique_constraint('UserLoggedIn_userName_key', 'UserLoggedIn', ['userName'], schema='core_user')
    # ### end Alembic commands ###
